#include <iostream>

#include "BackgroundSkyData.h"

typedef d5hdf::BackgroundSkyData::Lobe Lobe;
typedef d5hdf::BackgroundSkyData::LobeAnim LobeAnim;
typedef d5hdf::BackgroundSkyData::TimePoint TimePoint;

std::array<float, 3> sphericalDir(float theta, float phi) {
    return {
        std::sin(theta) * std::cos(phi),
        std::sin(theta) * std::sin(phi),
        std::cos(theta) 
    };
}

int main() {
  std::vector<float> spectralSamples = {0.4f, 0.5f, 0.6f};
  std::vector<float> spectralCurvesTable = {
      0.25f, 0.50f, 1.00f,
      1.00f, 0.15f, 0.25f,
      0.35f, 1.00f, 0.15f,
      1.00f, 0.85f, 0.15f
  };
  {
    std::vector<LobeAnim> lobeAnims;
    LobeAnim lobeAnim;
    Lobe lobes[5] = {};
    lobes[0].setHGFromThetaLimit(0.7f).setRelTime(0.00f).setCurveIndex(0);
    lobes[1].setHGFromThetaLimit(0.9f).setRelTime(0.25f).setCurveIndex(1);
    lobes[2].setHGFromThetaLimit(1.2f).setRelTime(0.50f).setCurveIndex(2);
    lobes[3].setHGFromThetaLimit(1.1f).setRelTime(0.75f).setCurveIndex(3);
    lobes[4].setHGFromThetaLimit(0.7f).setRelTime(1.00f).setCurveIndex(0);
    lobes[0].setLocalTransform(sphericalDir(0.707f, 0.000f));
    lobes[1].setLocalTransform(sphericalDir(1.046f, 2.355f));
    lobes[2].setLocalTransform(sphericalDir(0.523f, 4.622f));
    lobes[3].setLocalTransform(sphericalDir(0.000f, 0.000f));
    lobes[4].setLocalTransform(sphericalDir(0.707f, 0.000f));
    lobeAnim.lobes.push_back(lobes[0]);
    lobeAnim.lobes.push_back(lobes[1]);
    lobeAnim.lobes.push_back(lobes[2]);
    lobeAnim.lobes.push_back(lobes[3]);
    lobeAnim.lobes.push_back(lobes[4]);
    lobeAnim.referenceTime.type = TimePoint::Type::Diurnal;
    lobeAnim.name = "Periodic";
    lobeAnims.push_back(lobeAnim);

    d5hdf::BackgroundSkyData::WriteToFile(
        "demo_lobes.h5",
        d5hdf::BackgroundSkyData(spectralSamples, spectralCurvesTable,
                                 lobeAnims));
  }

  return 0;
}
